@@ -44,6 +44,8 @@ def _shuffle_items(items, bucket_key=None, disable=None, seed=None, session=None
     # If `bucket_key` is falsey, shuffle is global.
     if not bucket_key and not disable:
         random.shuffle(items)
+        if num > -1:
+            items = items[:num]
         return
 
     def get_full_bucket_key(item):
